@@ -49,7 +49,6 @@ class Post(AbstractRequest):
         t_id = Post.thing(name, long_name, location_id=l_id)
         o_id = Post.observed_property(name, long_name, definition)
         s_id = Post.sensor(name, long_name, encoding_type)
-        print(name, description, unit, ob_type, t_id, o_id, s_id)
 
         return Post.datastream(name, description, unit, ob_type, t_id, o_id, s_id)
 
@@ -83,25 +82,6 @@ class Post(AbstractRequest):
             properties=properties, thing_id=thing_id)
         return Post.entity(Entity.Location, **params)
 
-    # @staticmethod
-    # def location(name, description, encoding_type, loc_type, loc_coords, properties=None, thing_id=None):
-    #     """
-    #     Create a new Location with the given data filled in
-    #     :param name: the name for the Location
-    #     :param description: the description for the Location
-    #     :param encoding_type: the encodingType for the Location
-    #     :param loc_type: the type of location according to the GeoJSON-Standard
-    #     :param loc_coords: coordinates formatted according to the defined type in loc_type
-    #     :param properties: a dict of additional (meta-)data for the Location
-    #     :param thing_id: the ID of the associated Thing
-    #     :return: the ID of the newly created Location
-    #     """
-    #     location = {
-    #         "type": loc_type,
-    #         "coordinates": loc_coords
-    #     }
-    #     return Post.location(name, description, encoding_type, location, properties=properties, thing_id=thing_id)
-
     @staticmethod
     def observation(phenomenon_time, result, result_quality=None, valid_time=None, parameters=None,
         datastream_id=None, feature_of_interest_id=None):
